@@ -1355,8 +1355,9 @@ zoneinit(struct state *sp, char const *name)
 }
 
 static void
-tzsetlcl(char const *name)
+tzset_unlocked(void)
 {
+  char const *name = getenv("TZ");
   struct state *sp = lclptr;
   int lcl = name ? strlen(name) < sizeof lcl_TZname : -1;
   if (lcl < 0
@@ -1377,23 +1378,6 @@ tzsetlcl(char const *name)
   lcl_is_set = lcl;
 }
 
-#ifdef STD_INSPIRED
-void
-tzsetwall(void)
-{
-  if (lock() != 0)
-    return;
-  tzsetlcl(NULL);
-  unlock();
-}
-#endif
-
-static void
-tzset_unlocked(void)
-{
-  tzsetlcl(getenv("TZ"));
-}
-
 void
 tzset(void)
 {
